utilities
=========

.. image:: https://travis-ci.org/pyoceans/ioos_tools.svg?branch=master
   :target: https://travis-ci.org/pyoceans/ioos_tools
   :alt: build status
.. image:: https://zenodo.org/badge/100956238.svg
   :target: https://zenodo.org/badge/latestdoi/100956238
   :alt: doi
.. image:: https://img.shields.io/pypi/l/ioos_tools.svg
   :target: https://github.com/pyoceans/ioos_tools/blob/master/LICENSE.txt
   :alt: PyPI - License



IOOS/SECOORA utilities functions.
---------------------------------

A collection of misc functions used in IOOS Data Demo Center `notebooks examples <https://ioos.github.io/notebooks_demos/>`__.
